| salso-package | R Documentation |
The SALSO algorithm is an efficient randomized greedy search method to find a point estimate for a random partition based on a loss function and posterior Monte Carlo samples. The algorithm is implemented for many loss functions, including the Binder loss and a generalization of the variation of information loss, both of which allow for unequal weights on the two types of clustering mistakes. Efficient implementations are also provided for Monte Carlo estimation of the posterior expected loss of a given clustering estimate. See Dahl, Johnson, Müller (2022) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/10618600.2022.2069779")}.
Maintainer: David B. Dahl dahl@stat.byu.edu (ORCID)
Authors:
Devin J. Johnson devin.j.johnson7@gmail.com (ORCID)
Peter Müller pmueller@math.utexas.edu
Andrés Felipe Barrientos abarrientos@fsu.edu
Garritt Page page@stat.byu.edu
David Dunson dunson@duke.edu
Other contributors:
Authors of the dependency Rust crates (see inst/AUTHORS file for details) [contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.