| synthetic | R Documentation |
Synthetic Dataset for CHIPS Demo
data(synthetic)
A list with elements partitions, data, and means as described.
A small synthetic dataset used in the CHIPS demo.
Load with data("synthetic", package = "salso") to get a list with
the following components:
partitions: integer matrix of size B x n giving B sampled
clusterings (rows) of n items (columns), encoded with cluster labels.
data: numeric matrix of size n x 2 giving the two-dimensional
observations used to generate the partitions.
means: numeric array of size B x K x 2 giving cluster-specific means
across MCMC iterations (B), for each cluster (K) and dimension (2).
See also the CHIPS demo: demo("chips", package = "salso").
chips
data(synthetic)
str(synthetic)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.