Learn R Programming

salso (version 0.3.79)

salso-package: salso: Search Algorithms and Loss Functions for Bayesian Clustering

Description

The SALSO algorithm is an efficient randomized greedy search method to find a point estimate for a random partition based on a loss function and posterior Monte Carlo samples. The algorithm is implemented for many loss functions, including the Binder loss and a generalization of the variation of information loss, both of which allow for unequal weights on the two types of clustering mistakes. Efficient implementations are also provided for Monte Carlo estimation of the posterior expected loss of a given clustering estimate. See Dahl, Johnson, Müller (2022) tools:::Rd_expr_doi("10.1080/10618600.2022.2069779").

Arguments

Author

Maintainer: David B. Dahl [email protected] (ORCID)

Authors:

Other contributors:

  • Authors of the dependency Rust crates (see inst/AUTHORS file for details) [contributor]

See Also