Learn R Programming

salso (version 0.3.79)

synthetic: Synthetic Dataset for CHIPS Demo

Description

Synthetic Dataset for CHIPS Demo

Usage

data(synthetic)

Arguments

Format

A list with elements partitions, data, and means as described.

Details

A small synthetic dataset used in the CHIPS demo.

Load with data("synthetic", package = "salso") to get a list with the following components:

  • partitions: integer matrix of size B x n giving B sampled clusterings (rows) of n items (columns), encoded with cluster labels.

  • data: numeric matrix of size n x 2 giving the two-dimensional observations used to generate the partitions.

  • means: numeric array of size B x K x 2 giving cluster-specific means across MCMC iterations (B), for each cluster (K) and dimension (2).

See also the CHIPS demo: demo("chips", package = "salso").

See Also

chips

Examples

Run this code
data(synthetic)
str(synthetic)

Run the code above in your browser using DataLab